@@ -1,4 +1,5 @@
-
+import re
+from os import environ
 from contextlib import contextmanager
 import random
 from ssh_client.remote_client import RemoteClient
@@ -8,35 +9,70 @@ from ssh_client.helpers import remote_bat_file, generate_inmemory_file, generate
 
 RELATIVE_REMOTE_DIR = "bat_runner"
 ABSOLUTE_REMOTE_DIR = f"C:\\Users\\CASA\\Canper\\{RELATIVE_REMOTE_DIR}"
+HOST = environ.get('REMOTE_HOST')
+USER = environ.get('REMOTE_USER')
+PASSWORD = environ.get('REMOTE_PASSWORD')
 
 
 @contextmanager
 def client_manager():
     try:
-        client = RemoteClient('82.223.115.66', 'canper', '1234')
+        client = RemoteClient(HOST, USER, PASSWORD)
         client.connect()
         yield client
     finally:
         client.disconnect()
 
-def create_connection(connection):
-    file_name = f'setup_{connection.raspberry}_{random.randint(1,1000004)}'
+
+def _extract_rb(value):
+    return f'rb{re.search(r"rb(.*?)-", value).group(1)}'
+
+
+def send_connection_ovpn(conexion, conexion_id):
+    rb = _extract_rb(conexion)
 
     with client_manager() as client:
         # Create folder for this raspberry
         client.execute_commands([
-            f'cmd.exe /c "mkdir {ABSOLUTE_REMOTE_DIR}"\\{connection.raspberry}'
+            f'cmd.exe /c "mkdir {ABSOLUTE_REMOTE_DIR}"\\{rb}'
         ])
+
+        # setup_file_inmemory = generate_inmemory_file(ovpn_file.file.read())
+        client.upload_single_file_from_url(f'ficheros/raspberries/{conexion_id}/{conexion}.ovpn', f'{RELATIVE_REMOTE_DIR}/{rb}/{conexion}.ovpn')
+
+
+def delete_connection_ovpn(conexion):
+    rb = _extract_rb(conexion)
+
+    with client_manager() as client:
+        client.execute_commands([
+            # Remove ovpn file
+            f'cmd.exe /c "del {ABSOLUTE_REMOTE_DIR}\\{rb}\\{conexion}.ovpn"',
+        ])
+
+
+def create_connection(conexion, password, expiry_date):
+    rb = _extract_rb(conexion)
+    file_name = f'setup_{rb}_{random.randint(1,1000004)}'
+
+    with client_manager() as client:
+        # Create folder for this raspberry
+        client.execute_commands([
+            f'cmd.exe /c "mkdir {ABSOLUTE_REMOTE_DIR}"\\{file_name}'
+        ])
+        # Load file template
         setup_file_template = remote_bat_file('bats/setup.bat')
+
+        # Fullfill template with conecttion data
         setup_file_content = setup_file_template.format(
-            exe_passes=connection.exe_contraseña,
-            ids=connection.canper_id,
+            exe_passes=password,
+            ids=conexion,
             ovpn_passes='test',
-            expiry_dates='25/03/2021',
+            expiry_dates=expiry_date,
             expiry_times='23:59',
             folder=file_name
         )
-        setup_file_inmemory = generate_inmemory_file(setup_file_content)
+        setup_file_inmemory = generate_inmemory_file(setup_file_content.encode())
             
         client.upload_single_file(setup_file_inmemory, f'{RELATIVE_REMOTE_DIR}/{file_name}.bat')
 
@@ -45,10 +81,9 @@ def create_connection(connection):
             f'cmd.exe /c "{ABSOLUTE_REMOTE_DIR}\\{file_name}.bat"',
         ])
 
-        # Download generated EXE files to local
-        for i in range(1, number_connections + 1):
-            exe_file_name = f'{raspberry}-{i}.exe'
-            client.download_file(exe_file_name, f'{RELATIVE_REMOTE_DIR}/{file_name}/{exe_file_name}')
+        # Download generated EXE file to local
+        exe_file_name = f'{conexion}.exe'
+        exe_file = client.download_file_into_memory(exe_file_name, f'{RELATIVE_REMOTE_DIR}/{file_name}/{exe_file_name}')
 
         client.execute_commands([
             # Remove recursively folder setup_XXXX
@@ -57,10 +92,12 @@ def create_connection(connection):
             f'cmd.exe /c "del {ABSOLUTE_REMOTE_DIR}\\{file_name}.bat"',
         ])
 
+        return exe_file
 
-def create_exe_connections(number_connections, raspberry, ovpn_passes):
-    ids, exe_passes, ovpn_passes, expiry_dates, expiry_times = generate_file_data(number_connections, raspberry, ovpn_passes)
-    file_name = f'setup_{raspberry}_{random.randint(1,1000004)}'
+
+def refresh_exe_connections(connections, expiry_date):
+    ids, exe_passes, ovpn_passes, expiry_dates, expiry_times = generate_file_data(connections, expiry_date)
+    file_name = f'setup_{random.randint(1,1000004)}'
 
     with client_manager() as client:
         # Create folder for this raspberry
@@ -76,7 +113,7 @@ def create_exe_connections(number_connections, raspberry, ovpn_passes):
             expiry_times='\n'.join(expiry_times),
             folder=file_name
         )
-        setup_file_inmemory = generate_inmemory_file(setup_file_content)
+        setup_file_inmemory = generate_inmemory_file(setup_file_content.encode())
             
         client.upload_single_file(setup_file_inmemory, f'{RELATIVE_REMOTE_DIR}/{file_name}.bat')
 
@@ -86,8 +123,8 @@ def create_exe_connections(number_connections, raspberry, ovpn_passes):
         ])
 
         # Download generated EXE files to local
-        for i in range(1, number_connections + 1):
-            exe_file_name = f'{raspberry}-{i}.exe'
+        for c in connections:
+            exe_file_name = f'{c["canper_id"]}.exe'
             client.download_file(exe_file_name, f'{RELATIVE_REMOTE_DIR}/{file_name}/{exe_file_name}')
 
         client.execute_commands([
@@ -109,7 +146,7 @@ def check_connections(ids, ovpn_passes):
             ovpn_passes='\n'.join(ovpn_passes),
             file_name=f'{file_name}'
         )
-        check_file_inmemory = generate_inmemory_file(check_file)
+        check_file_inmemory = generate_inmemory_file(check_file.encode())
 
         client.upload_single_file(check_file_inmemory, f'{RELATIVE_REMOTE_DIR}/{file_name}.bat')
 
@@ -118,11 +155,20 @@ def check_connections(ids, ovpn_passes):
             f'cmd.exe /c "{ABSOLUTE_REMOTE_DIR}\\{file_name}.bat"',
             # Remove chech_XXX.bat
             f'cmd.exe /c "del {ABSOLUTE_REMOTE_DIR}\\{file_name}.bat"',
-            # Run chech_XXX.exe
+            # Run chech_XXX.exe. It will generate a log_XXXX.csv file
             f'cmd.exe /c "{ABSOLUTE_REMOTE_DIR}\\{file_name}.exe"',
             # Remove chech_XXX.exe
             f'cmd.exe /c "del {ABSOLUTE_REMOTE_DIR}\\{file_name}.exe"',
         ])
 
-# create_exe_connections(2, 'RB0202', '1234')
-# check_connections(['rb0202-1', 'rb0202-2'], ['11111', '11111'])
\ No newline at end of file
+        # Load log_XXXX.csv into memory
+        # Download generated EXE file to local
+        log_file_name = f'{file_name}.csv'
+        log_file = client.download_file_into_memory(log_file_name, f'{RELATIVE_REMOTE_DIR}/{log_file_name}')
+
+        client.execute_commands([
+            # Remove file log_XXXX.csv
+            f'cmd.exe /c "del {ABSOLUTE_REMOTE_DIR}\\{log_file_name}"',
+        ])
+
+        return log_file
